#[repr(C, align(64))]pub struct OptimizedRingSlot {
pub entry: OptimizedRingEntry,
pub payload: [u8; 56],
}Expand description
Cache-line aligned ring slot.
Each slot contains the entry header and inline payload data. Aligned to cache line for single cache line access per operation.
Fields
entry: OptimizedRingEntryEntry header.
payload: [u8; 56]Inline payload data (56 bytes max for 64-byte slot).
Implementations
Sourceimpl OptimizedRingSlot
impl OptimizedRingSlot
Sourcepub const MAX_INLINE_SIZE: usize = 56
pub const MAX_INLINE_SIZE: usize = 56
Maximum inline payload size.